#!/usr/bin/python
# -*- coding: UTF-8 -*-

import os
import pip
import json
import re
import platform



execute = lambda: "3" if (platform.system().lower() == "darwin") else ""


def Run(reponame):
    RootPath = pip.__path__[0]
    os.chdir(RootPath)
    os.chdir("..")
    try:os.chdir(".@GTFRepository90876")
    except FileNotFoundError: print("[!] There aren't any repositories installed."), exit()

    run = ""
    for repo in os.listdir():
        if (repo[0] == "."): continue
        elif (repo == reponame): 
            try:
                os.chdir(reponame)
                with open(".info") as file : run = json.loads(file.read())["main"]
            except : pass
        else: pass

    if not (run):
        Repository = os.listdir()
        DID = False
        for repo in Repository:
            if (repo[0] == "."): continue
            else:
                if (re.search(reponame.lower(), repo.lower()) == None): pass
                else: DID = True
        print(f"[!] Program not found '{reponame}'")
        if (DID): print(f"[+] Did you mean,\n")
        for repo in Repository:
            if (repo[0] == "."): continue
            else:
                if (re.search(reponame.lower(), repo.lower()) == None): pass
                else: print(f"    {repo}")
    else: os.system(f"python{execute()} {run}"), exit()



#!/usr/bin/python
# -*- coding: UTF-8 -*-

import sys
import requests
import shutil
import os
import pip
import zipfile
import random

from .GTF import install
from .GTF import run





__VERSION__ = "0.0.7"

source = "https://github.com/GreyTechno/gtf/archive/refs/heads/main.zip"
main = "mrdoxmrgt"


def Release():
    os.chdir(pip.__path__[0])
    os.chdir("..")

    try: shutil.rmtree(main)
    except FileNotFoundError: pass

    rname = "".join(random.sample("abcdefghijklmnopqrstuvwxyz", 15))
    zipname = source.split("/")[4] +"-"+ source.split("/")[-1].split(".")[0]

    with open(f"{rname}.zip", "wb") as file: file.write(requests.get(source).content)
    with zipfile.ZipFile(f"{rname}.zip", "r") as zip: zip.extractall(f"{rname}")
    os.remove(f"{rname}.zip")

    shutil.copytree(f"{os.getcwd()}/{rname}/{zipname}", main)
    shutil.rmtree(rname)

















def main():
    

    try: command = sys.argv[1]
    except: command = False

    try: arguments = sys.argv[2]
    except: arguments = ""

    try: arguments_01 = sys.argv[3:]
    except: arguments_01 = ""
    if (command):
        if (command == "install") or (command == "-install") or (command == "--install") or (command == "--clone") or (command == "--clone") or (command == "--clone"):
            install.Install(arguments)
        # elif (command == "uninstall") or (command == "-uninstall") or (command == "--uninstall"): pass
        # elif (command == "download") or (command == "-download") or (command == "--download"): pass
        # elif (command == "update") or (command == "-update") or (command == "--update"): print("update")
        elif (command == "run") or (command == "-run") or (command == "--run") or (command == "--start") or (command == "--start") or (command == "--start"):
            run.Run(arguments)
        # elif (command == "list") or (command == "-list") or (command == "--list"): print("list")
        # elif (command == "about") or (command == "-about") or (command == "--about"): pass
        # elif (command == "show") or (command == "-show") or (command == "--show"): pass
        # elif (command == "help") or (command == "-help") or (command == "--help"): pass
        else: print(f"ERROR : Command not found '{command}'\nShow help 'gtf -h'")
if __name__ == "__main__":
    version = requests.get("https://raw.githubusercontent.com/GreyTechno/gtf/main/.info").json()["version"]
    if (__VERSION__ != version): Release()
    main()


from setuptools import setup, find_packages

setup(
    name='mrdoxmrgt',
    packages=find_packages(),
    include_package_data=True,
    version="0.0.8",
    description='A small example package',
    long_description="A small example package HI",
    long_description_content_type="text/markdown",
    author='MR_GT',
    author_email='friendyt89@gmail.com',
    url='https://github.com/GreyTechno/SMS_Forwarder',
    download_url="https://github.com/GreyTechno/gtf/archive/pypi.zip",
        keywords=['a1', 'a2', 'a3', 'a3', 'a4',
                  'a5', 'a6', 'a7', 'a8', 'a9'],
    classifiers=[
            'Development Status :: 4 - Beta',
            'Intended Audience :: Developers',
            'Topic :: Software Development :: Libraries :: Python Modules',
            'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
            'Programming Language :: Python :: 3',
            'Operating System :: OS Independent',
            'Environment :: Console',
    ],
    install_requires=["requests"],
    license='GPL',
    entry_points={
            'console_scripts': [
                'mrdoxmrgt = mrdoxmrgt._main_:main',
            ],
    },
    python_requires='>=3.5'
)



#!/usr/bin/python
# -*- coding: UTF-8 -*-

import os
import subprocess
import shutil
import pip
import json
import re
import requests
import threading
import zipfile
import random
import sys
import time
import platform


execute = lambda: "3" if (platform.system().lower() == "darwin") else ""



def AnimLOAD(text):
    for handlechar in "⠋⠙⠹⠸⠼⠴⠦⠧⠇⠏":
        sys.stdout.write(f"\r{handlechar} {text}")
        sys.stdout.flush()
        time.sleep(0.04)




def Install(reponame):
    Repository = requests.get("https://raw.githubusercontent.com/GreyTechno/Binaries/main/files/.repository").json()
    RootPath = pip.__path__[0]

    os.chdir(RootPath)
    os.chdir("..")
    try:os.chdir(".@GTFRepository90876")
    except FileNotFoundError:
        os.mkdir(".@GTFRepository90876")
        with open(".info", "w") as file : file.write("")
        os.chdir(".@GTFRepository90876")

    if not (reponame in Repository):
        DID = False
        for repo in Repository:
            if (repo[0] == "."): continue
            else:
                if (re.search(reponame.lower(), repo.lower()) == None): pass
                else: DID = True
        if (len(reponame) == 0): print(f"[!] Program not found")
        else:
            print(f"[!] Program not found '{reponame}'")
            if (DID): print(f"[+] Did you mean,\n")
            for repo in Repository:
                if (repo[0] == "."): continue
                else:
                    if (re.search(reponame.lower(), repo.lower()) == None): pass
                    else: print(f"    {repo}")
    else:
        source = Repository[reponame]['zipurl']
        dependencies = Repository[reponame]['dependencies']
        rname = "".join(random.sample("abcdefghijklmnopqrstuvwxyz", 7))
        zipname = source.split("/")[4] +"-"+ source.split("/")[-1].split(".")[0]
        toolname = zipname.split("-")[0]
        if (reponame in os.listdir()):
            print("[!] '{}' already installed.".format(reponame))
        else:
            def _():
                with open(f"{rname}.zip", "wb") as file: file.write(requests.get(source).content)
                with zipfile.ZipFile(f"{rname}.zip", "r") as zip: zip.extractall(f"{rname}")
                os.remove(f"{rname}.zip")
                shutil.copytree(f"{os.getcwd()}/{rname}/{zipname}", toolname)
                shutil.rmtree(rname)
            install = threading.Thread(target=_)
            install.start()
            while install.is_alive(): AnimLOAD("Installing " + reponame + "...")
            install.join()
            sys.stdout.write(f"\r[+] {reponame} installed.  \n")
            Dependencies = lambda: [subprocess.getoutput(f"pip{execute()} install {i}") for i in dependencies]
            DEPENDENCIES = threading.Thread(target=Dependencies)
            DEPENDENCIES.start()
            while DEPENDENCIES.is_alive(): AnimLOAD("Installing Building Dependencies...")
            DEPENDENCIES.join()
            sys.stdout.write("\r[+] Installtion Completed.           \n")
            print("[-] For start >> 'gtf run {}'".format(reponame))